summary refs log tree commit diff stats
path: root/src/fe-gtk/palette.c
diff options
context:
space:
mode:
authorBerke Viktor <bviktor@hexchat.org>2012-10-30 11:35:39 +0100
committerBerke Viktor <bviktor@hexchat.org>2012-10-30 11:35:39 +0100
commita51a69134b8bdc94cfb4dcc1403e33cce24d34bc (patch)
treea257e588c8d13d8d275450b8903c924145e5835f /src/fe-gtk/palette.c
parent82936df2af3993c2e234042c450e0e9630b045d4 (diff)
Nah, even more rebranding
Diffstat (limited to 'src/fe-gtk/palette.c')
-rw-r--r--src/fe-gtk/palette.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/fe-gtk/palette.c b/src/fe-gtk/palette.c
index ffa627d5..8866dda7 100644
--- a/src/fe-gtk/palette.c
+++ b/src/fe-gtk/palette.c
@@ -104,7 +104,7 @@ palette_alloc (GtkWidget * widget)
 	}
 }
 
 /* maps XChat 2.0.x colors to current */
 static const int remap[] =
 {
 	0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,
@@ -128,10 +128,10 @@ palette_load (void)
 	int red, green, blue;
 	int upgrade = FALSE;
 
-	fh = xchat_open_file ("colors.conf", O_RDONLY, 0, 0);
+	fh = hexchat_open_file ("colors.conf", O_RDONLY, 0, 0);
 	if (fh == -1)
 	{
-		fh = xchat_open_file ("palette.conf", O_RDONLY, 0, 0);
+		fh = hexchat_open_file ("palette.conf", O_RDONLY, 0, 0);
 		upgrade = TRUE;
 	}
 
@@ -210,7 +210,7 @@ palette_save (void)
 	int i, j, fh;
 	char prefname[256];
 
-	fh = xchat_open_file ("colors.conf", O_TRUNC | O_WRONLY | O_CREAT, 0600, XOF_DOMODE);
+	fh = hexchat_open_file ("colors.conf", O_TRUNC | O_WRONLY | O_CREAT, 0600, XOF_DOMODE);
 	if (fh != -1)
 	{
 		/* mIRC colors 0-31 are here */
@@ -104,7 +104,7 @@ palette_alloc (GtkWidget * widget)
 }
 
-/* maps XChat 2.0.x colors to current */
+/* maps HexChat 2.0.x colors to current */
 static const int remap[] =
 {